@@ -87,6 +87,27 @@ def _upload_firmware_stm32f407():
         raise RuntimeError("Failed to upload the firmware to the board")
 
 
+def _upload_firmware_stm32f411():
+    tools_folder = board_tools_folder(Boards.STM32F411E_DISCO)
+    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
+
+    command = '%s --connect port=SWD ap=0' % programmer_path
+    log.debug(command)
+
+    res = subprocess.Popen(
+        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
+    log.debug(res)
+    if 'f411x' not in res.lower():
+        raise RuntimeError("Failed to connect to the board")
+
+    firmware_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'firmware/stm32f411e-disco-demo.elf')
+    command = '%s --connect port=SWD ap=0 -w %s -hardRst' % (programmer_path, firmware_path)
+    log.debug(command)
+
+    if subprocess.run(command, **subprocess_run_kwargs).returncode != 0:
+        raise RuntimeError("Failed to upload the firmware to the board")
+
+
 def _upload_firmware_stm32h747():
     tools_folder = board_tools_folder(Boards.STM32H747I_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -127,7 +148,7 @@ def upload_firmware(board):
     elif board is Boards.STM32F407G_DISCO:
         _upload_firmware_stm32f407()
     elif board is Boards.STM32F411E_DISCO:
-        raise NotImplementedError()
+        _upload_firmware_stm32f411()
     elif board is Boards.STM32F469I_DISCO:
         _upload_firmware_stm32f469()
     elif board is Boards.STM32H747I_DISCO:
